==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/siteattachmentbearer/bearer/DefaultRequestedType.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.siteattachmentbearer.bearer;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of requestedType.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultRequestedType extends InnerModelObject implements RequestedType {
    protected String requestedType;
    protected boolean strict;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String requestedType() {
        return requestedType;
    }

    @Override
    public boolean strict() {
        return strict;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void requestedType(String requestedType) {
        valueLeafFlags.set(LeafIdentifier.REQUESTEDTYPE.getLeafIndex());
        this.requestedType = requestedType;
    }

    @Override
    public void strict(boolean strict) {
        valueLeafFlags.set(LeafIdentifier.STRICT.getLeafIndex());
        this.strict = strict;
    }

    @Override
    public int hashCode() {
        return Objects.hash(requestedType, strict, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultRequestedType) {
            DefaultRequestedType other = (DefaultRequestedType) obj;
            return
                Objects.equals(requestedType, other.requestedType) &&
                Objects.equals(strict, other.strict) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("requestedType=" + requestedType)
            .add("strict=" + strict)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultRequestedType.
     */
    public DefaultRequestedType() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/siteattachmentbearer/bearer/DefaultRequestedType.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.siteattachmentbearer.bearer;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of requestedType.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultRequestedType extends InnerModelObject implements RequestedType {
    protected String requestedType;
    protected boolean strict;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String requestedType() {
        return requestedType;
    }

    @Override
    public boolean strict() {
        return strict;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void requestedType(String requestedType) {
        valueLeafFlags.set(LeafIdentifier.REQUESTEDTYPE.getLeafIndex());
        this.requestedType = requestedType;
    }

    @Override
    public void strict(boolean strict) {
        valueLeafFlags.set(LeafIdentifier.STRICT.getLeafIndex());
        this.strict = strict;
    }

    @Override
    public int hashCode() {
        return Objects.hash(requestedType, strict, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultRequestedType) {
            DefaultRequestedType other = (DefaultRequestedType) obj;
            return
                Objects.deepEquals(requestedType, other.requestedType) &&
                Objects.deepEquals(strict, other.strict) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("requestedType=" + requestedType)
            .add("strict=" + strict)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultRequestedType.
     */
    public DefaultRequestedType() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
